@@ -276,7 +276,7 @@ class KigDOP(object):
 
 #class KigView(KigOut):
 class KigView(object):
-  """A class containing visualisation data.
+  """A class containing visualization data.
 
     ancestor chain:
       KigView <- object
@@ -561,6 +561,8 @@ objects=(\
                     "conic, line, which,", "(conic, line, Int(which),),"),
 ("ConicLineOtherIntersection", "ConicLineOtherIntersection",
            	    "conic, line, p,", "(conic, line, p),"),
+("LineCubicIntersection", "CubicLineIntersection",
+                    "cubic, line, which,", "(cubic, line, Int(which),),"),
 ("CubicLineIntersection", "CubicLineIntersection",
                     "cubic, line, which,", "(cubic, line, Int(which),),"),
 ("CubicLineOtherIntersection", "CubicLineOtherIntersection", "cubic, line, p1, p2,", "(cubic, line, p1, p2),"),
